===============================
lsys
===============================


.. image:: https://img.shields.io/pypi/v/lsys.svg
        :target: https://pypi.python.org/pypi/lsys

.. image:: https://img.shields.io/travis/austinorr/lsys.svg
        :target: https://travis-ci.org/austinorr/lsys

.. image:: https://codecov.io/gh/austinorr/lsys/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/austinorr/lsys
        :alt: Code Coverage


Create and visualize lindenmayer systems.


* Free software: BSD license
* Documentation: https://austinorr.github.io/lsys/


Features
--------

* TODO
